/**
 * @providesModule AppState
 * @flow
 */
'use strict';

function throwMissingNativeModule() {
  console.warn(
    'Cannot use AppState module when native RCTAppState is not included in the build.\n' +
    'Either include it, or check AppState.isAvailable before calling any methods.'
  );
}

class MissingNativeAppStateShim {
  // AppState
  isAvailable: boolean = false;
  currentState: ?string = null;

  addEventListener() {
    throwMissingNativeModule();
  }

  removeEventListener() {
    throwMissingNativeModule();
  }

  // EventEmitter
  addListener() {
    throwMissingNativeModule();
  }

  removeAllListeners() {
    throwMissingNativeModule();
  }

  removeSubscription() {
    throwMissingNativeModule();
  }
}

// This module depends on the native `RCTAppState` module. If you don't include it,
// `AppState.isAvailable` will return `false`, and any method calls will throw.
// We reassign the class variable to keep the autodoc generator happy.
var AppState = new MissingNativeAppStateShim();

module.exports = AppState;
