'use strict';

var path = require('path');
var webpack = require('webpack');
var HtmlWebpackPlugin = require('html-webpack-plugin');
var UglifyJsPlugin = require('uglifyjs-webpack-plugin');
var merge = require('webpack-merge');
var config = require('./config').build;
var baseWebpackConfig = require('./webpack.config.base');

module.exports = merge({}, baseWebpackConfig, {
  devtool: '#source-map',
  mode: 'production',
  output: {
    filename: '[name].js',
    chunkFilename: '[id].[chunkhash].js'
  },
  optimization: {
    runtimeChunk: {
      name: 'mainifest'
    },
    splitChunks: {
      maxInitialRequests: 6,
      cacheGroups: {
        'vendor': {
          //第三方依赖
          priority: 1,
          name: 'vendor',
          test: /node_modules/,
          chunks: 'initial',
          minSize: 100,
          minChunks: 1 //重复引入了几次
        }
      }
    },
    minimizer: [
      new UglifyJsPlugin({
        uglifyOptions: {
          compress: false,
          mangle: true,
          output: {
            comments: false,
          },
        }
      })
    ]
  },
  plugins: [
    new webpack.DefinePlugin({
      "process.env": {
        'NODE_ENV': JSON.stringify('production'),
      },
      '__DEV__': false
    }),
    new HtmlWebpackPlugin({
      filename: `index.html`,
      hash: true,
      template: path.join(__dirname, 'index.tpl.vm'),
      config: config.template,
    })
  ]
})
